@@ -83,7 +83,7 @@ static gboolean update_function (gpointer data){
 
   plugin_data *pd=(plugin_data *)data;
   gint elapsed_sec,remaining;
-  gchar tiptext[64];
+  gchar *tiptext = NULL;
   GtkWidget *dialog;
 
   elapsed_sec=(gint)g_timer_elapsed(pd->timer,NULL);
@@ -97,12 +97,12 @@ static gboolean update_function (gpointer data){
      remaining=pd->timeout_period_in_sec-elapsed_sec;
 
      if(remaining>=3600)
-       g_snprintf(tiptext,31,_("%dh %dm %ds left"),remaining/3600, (remaining%3600)/60,
+       tiptext = g_strdup_printf(_("%dh %dm %ds left"),remaining/3600, (remaining%3600)/60,
             remaining%60);
      else if (remaining>=60)
-       g_snprintf(tiptext,31,_("%dm %ds left"),remaining/60, remaining%60);
+       tiptext = g_strdup_printf(_("%dm %ds left"),remaining/60, remaining%60);
      else
-       g_snprintf(tiptext,31,_("%ds left"),remaining);
+       tiptext = g_strdup_printf(_("%ds left"),remaining);
        
      if(pd->is_paused)
        g_strlcat(tiptext,_(" (Paused)"),64);
@@ -112,6 +112,8 @@ static gboolean update_function (gpointer data){
 
      gtk_tooltips_set_tip(pd->tip,GTK_WIDGET(pd->base),tiptext,NULL);
 
+     g_free(tiptext);
+
      return TRUE;
 
   }
@@ -123,7 +125,7 @@ static gboolean update_function (gpointer data){
   if( (strlen(pd->timeout_command)==0) || !pd->nowin_if_alarm ) {
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(pd->pbar),1);
     dialog = gtk_message_dialog_new     (NULL,
-                                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                                    GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
                                     GTK_MESSAGE_WARNING,
                                     GTK_BUTTONS_CLOSE,
                                     _("Beeep! :) \nTime is up!"));
@@ -394,7 +396,7 @@ void make_menu(plugin_data *pd){
   GSList *group=NULL;
   GtkWidget *menuitem;
   gchar *timername,*timerinfo;
-  gchar itemtext[256];
+  gchar *itemtext = NULL;
   gint row_count;
 
 
@@ -436,7 +438,7 @@ void make_menu(plugin_data *pd){
       /*g_fprintf(stderr,"\nMaking menuitem %d while selected is %d",row_count,pd->
                                 selected);*/
       gtk_tree_model_get(GTK_TREE_MODEL(pd->list),&iter,1,&timername,2,&timerinfo,-1);
-      g_snprintf(itemtext,255,"%s (%s)",timername,timerinfo);
+      itemtext = g_strdup_printf("%s (%s)",timername,timerinfo);
       menuitem=gtk_radio_menu_item_new_with_label(group,itemtext);
       gtk_widget_show(menuitem);
       g_free(timername);
@@ -454,6 +456,7 @@ void make_menu(plugin_data *pd){
       gtk_menu_shell_append(GTK_MENU_SHELL(pd->menu),menuitem);
 
       /*g_fprintf(stderr,"\nAdding menuitem with label : %s",itemtext);*/
+      g_free(itemtext);
 
       /* We add the address of menuitem to the array */
       g_array_append_val(pd->menuarray,menuitem);
@@ -516,7 +519,7 @@ static void ok_add(GtkButton *button, gpointer data){
   alarm_data *adata = (alarm_data *)data;
   GtkTreeIter iter;
   gint t1,t2,t3,t;
-  gchar timeinfo[16];
+  gchar *timeinfo = NULL;
 
   /* Add item to the list */
   gtk_list_store_append(adata->pd->list,&iter);
@@ -541,11 +544,11 @@ static void ok_add(GtkButton *button, gpointer data){
 
     gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,5,t,-1);
     if(t1>0)
-       g_snprintf(timeinfo,15,_("%dh %dm %ds"),t1,t2,t3);
+       timeinfo = g_strdup_printf(_("%dh %dm %ds"),t1,t2,t3);
     else if(t2>0)
-       g_snprintf(timeinfo,15,_("%dm %ds"),t2,t3);
+       timeinfo = g_strdup_printf(_("%dm %ds"),t2,t3);
     else
-       g_snprintf(timeinfo,15,_("%ds"),t3);
+       timeinfo = g_strdup_printf(_("%ds"),t3);
 
     gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,2,timeinfo,-1);
   }
@@ -555,7 +558,7 @@ static void ok_add(GtkButton *button, gpointer data){
     t2=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(adata->time_m));
     t=t1*60+t2;
     gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,5,t,-1);
-    g_snprintf(timeinfo,9,_("At %02d:%02d"),t1,t2);
+    timeinfo = g_strdup_printf(_("At %02d:%02d"),t1,t2);
     gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,2,timeinfo,-1);
 
   }
@@ -567,6 +570,7 @@ static void ok_add(GtkButton *button, gpointer data){
   gtk_widget_destroy(GTK_WIDGET(adata->window));
 
   g_free(adata);
+  g_free(timeinfo);
 }
 
 
@@ -593,7 +597,7 @@ static void ok_edit(GtkButton *button, gpointer data){
   alarm_data *adata = (alarm_data *)data;
   GtkTreeIter iter;
   gint t1,t2,t3,t;
-  gchar timeinfo[10];
+  gchar *timeinfo = NULL;
 
   GtkTreeSelection *select;
   GtkTreeModel *model;
@@ -614,12 +618,12 @@ static void ok_edit(GtkButton *button, gpointer data){
         t3=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(adata->times));
         t=t1*3600+t2*60+t3;
         gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,5,t,-1);
-       if(t1>0)
-          g_snprintf(timeinfo,15,_("%dh %dm %ds"),t1,t2,t3);
-       else if(t2>0)
-          g_snprintf(timeinfo,15,_("%dm %ds"),t2,t3);
-       else
-          g_snprintf(timeinfo,15,_("%ds"),t3);
+        if(t1>0)
+           timeinfo = g_strdup_printf(_("%dh %dm %ds"),t1,t2,t3);
+        else if(t2>0)
+           timeinfo = g_strdup_printf(_("%dm %ds"),t2,t3);
+        else
+           timeinfo = g_strdup_printf(_("%ds"),t3);
 
         gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,2,timeinfo,-1);
       }
@@ -629,7 +633,7 @@ static void ok_edit(GtkButton *button, gpointer data){
         t2=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(adata->time_m));
         t=t1*60+t2;
         gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,5,t,-1);
-        g_snprintf(timeinfo,9,_("At %02d:%02d"),t1,t2);
+        timeinfo = g_strdup_printf(_("At %02d:%02d"),t1,t2);
         gtk_list_store_set(GTK_LIST_STORE(adata->pd->list),&iter,2,timeinfo,-1);
 
       }
@@ -641,6 +645,7 @@ static void ok_edit(GtkButton *button, gpointer data){
   gtk_widget_destroy(GTK_WIDGET(adata->window));
 
   g_free(adata);
+  g_free(timeinfo);
 }
 
 /**
@@ -679,6 +684,7 @@ static void add_edit_clicked (GtkButton *buttonn, gpointer data){
 
   plugin_data *pd = (plugin_data *)data;
 
+  GtkWindow *parent_window;
   GtkWindow *window;
   GtkLabel *label;
   GtkEntry *name,*command;
@@ -697,6 +703,9 @@ static void add_edit_clicked (GtkButton *buttonn, gpointer data){
   adata->pd=pd;
 
   gtk_window_set_modal(GTK_WINDOW(window),TRUE);
+  parent_window = (GtkWindow *) gtk_widget_get_toplevel(GTK_WIDGET(buttonn));
+  if (gtk_widget_is_toplevel(GTK_WIDGET(parent_window)))
+      gtk_window_set_transient_for(GTK_WINDOW(window), GTK_WINDOW(parent_window));
 
   vbox=gtk_vbox_new(FALSE, BORDER);
   gtk_container_add(GTK_CONTAINER(window),vbox);
@@ -1002,8 +1011,6 @@ static void down_clicked(GtkButton *button, gpointer data){
 **/
 static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
 
-  //g_signal_handler_disconnect (G_OBJECT(plugin), pd->handler);
-
   gtk_widget_hide(GTK_WIDGET(plugin));
 
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
@@ -1018,7 +1025,11 @@ static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
   /* vertical bar */
   if(xfce_panel_plugin_get_orientation(plugin)==GTK_ORIENTATION_HORIZONTAL){
     pd->box=gtk_hbox_new(TRUE,0);
+#ifdef HAVE_XFCE48    
     gtk_container_add(GTK_CONTAINER(plugin),pd->box);
+#else    
+    gtk_container_add(GTK_CONTAINER(pd->eventbox),pd->box);
+#endif
     gtk_progress_bar_set_orientation    (GTK_PROGRESS_BAR(pd->
                     pbar),GTK_PROGRESS_BOTTOM_TO_TOP);
     gtk_widget_set_size_request(GTK_WIDGET(pd->pbar),PBAR_THICKNESS,0);
@@ -1029,7 +1040,11 @@ static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
   }
   else{ /* horizontal bar */
     pd->box=gtk_vbox_new(TRUE,0);
+#ifdef HAVE_XFCE48    
     gtk_container_add(GTK_CONTAINER(plugin),pd->box);
+#else    
+    gtk_container_add(GTK_CONTAINER(plugin),pd->eventbox);
+#endif
     gtk_progress_bar_set_orientation    (GTK_PROGRESS_BAR(pd->
                     pbar),GTK_PROGRESS_LEFT_TO_RIGHT);
     gtk_widget_set_size_request(GTK_WIDGET(pd->pbar),0,PBAR_THICKNESS);
@@ -1039,10 +1054,11 @@ static void add_pbar(XfcePanelPlugin *plugin, plugin_data *pd){
 
   }
   
-  gtk_widget_show_all(GTK_WIDGET(plugin));
-
-  g_signal_connect  (G_OBJECT(plugin), "button_press_event",
-            G_CALLBACK(pbar_clicked), pd);       
+#ifdef HAVE_XFCE48
+  gtk_widget_show_all(GTK_WIDGET(plugin)); 
+#else
+  gtk_widget_show_all(GTK_WIDGET(pd->eventbox));
+#endif
 }
 
 /**
@@ -1266,12 +1282,6 @@ static void tree_selected (GtkTreeSelection *select, gpointer data){
 static void
 plugin_free (XfcePanelPlugin *plugin, plugin_data *pd)
 {
-  /*plugin_data *pd;
-
-  g_return_if_fail(ctrl != NULL);
-  g_return_if_fail(ctrl-> data != NULL);
-
-  pd = (plugin_data*) ctrl->data;*/
 
   /* remove timeouts */
   if (pd->timeout!=0) g_source_remove(pd->timeout);
@@ -1294,15 +1304,13 @@ plugin_free (XfcePanelPlugin *plugin, plugin_data *pd)
     g_array_free(pd->menuarray,TRUE);
 
   /* destroy all widgets */
+#ifndef HAVE_XFCE48
+	gtk_widget_destroy(GTK_WIDGET(pd->eventbox));
+#endif  
 
   /* destroy the tooltips */
   /*gtk_object_destroy(GTK_OBJECT(pd->tip));*/
 
-  //if(G_IS_OBJECT(pd->list))
-  //  g_free(pd->list);
-  //else
-  //  g_fprintf(stderr,"\npd->list is non-object");
-
   /* free the plugin data structure */
   g_free(pd);
 
@@ -1569,6 +1577,9 @@ create_plugin_control (XfcePanelPlugin *plugin)
          G_TYPE_INT);    /* Timer period in seconds if countdown.
                     Alarm time in minutes if 24h format is used,
                     (i.e. 60 x Hr + Min) */
+#ifndef HAVE_XFCE48
+  pd->eventbox = gtk_event_box_new();
+#endif  
   pd->box=NULL;
   pd->timer_on=FALSE;
   pd->timeout=0;
@@ -1618,6 +1629,15 @@ create_plugin_control (XfcePanelPlugin *plugin)
   gtk_widget_set_size_request(GTK_WIDGET(plugin),10,10);
   xfce_panel_plugin_set_expand(plugin,FALSE);
 
+#ifdef HAVE_XFCE48
+  g_signal_connect  (G_OBJECT(plugin), "button_press_event",
+            G_CALLBACK(pbar_clicked), pd);      
+#else
+  gtk_container_add(GTK_CONTAINER(plugin),pd->eventbox);
+  g_signal_connect  (G_OBJECT(pd->eventbox), "button_press_event",
+            G_CALLBACK(pbar_clicked), pd);
+#endif  
+
   gtk_widget_show_all(GTK_WIDGET(plugin));
 
   g_signal_connect (plugin, "free-data",
